% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bundles.R
\name{bundles}
\alias{bundles}
\alias{bundles_facets}
\alias{bundles_default_columns}
\alias{bundles_detail}
\title{HCA Bundle Querying}
\usage{
bundles(
  filters = NULL,
  size = 1000L,
  sort = "projectTitle",
  order = c("asc", "desc"),
  catalog = NULL,
  as = c("tibble", "lol", "list"),
  columns = bundles_default_columns("character")
)

bundles_facets(facet = character(), catalog = NULL)

bundles_default_columns(as = c("tibble", "character"))

bundles_detail(uuid, catalog = NULL)
}
\arguments{
\item{filters}{filter object created by \code{filters()}, or \code{NULL}
(default; all projects).}

\item{size}{integer(1) maximum number of results to return;
default: all projects matching \code{filter}. The default (10000) is
meant to be large enough to return all results.}

\item{sort}{character(1) project facet (see \code{facet_options()}) to
sort result; default: \code{"projectTitle"}.}

\item{order}{character(1) sort order. One of \code{"asc"} (ascending) or
\code{"desc"} (descending).}

\item{catalog}{character(1) source of data. Use
\code{catalogs()} for possible values.}

\item{as}{character(1) return format. Default: \code{"tibble"}, a tibble
summarizing essential elements of HCA projects. \code{"lol"}: a
representation of the JSON returned by the query as a
'list-of-lists' data structure, indexed and presented to enable
convenient filtering, selection, and extraction. \code{"list"} an R
list (typically, highly recursive) containing detailed project
information, constructed from the JSON response to the original
query.}

\item{columns}{named character() indicating the paths to be used
for parsing the 'lol' returned from the HCA to a tibble. The
names of \code{columns} are used as column names in the returned
tibble.}

\item{facet}{character() of valid facet names. Summary results (see
'Value', below) are returned when missing or length greater
than 1; details are returned when a single facet is specified.}

\item{uuid}{character() unique identifier (e.g., \code{projectId}) of
the object.}
}
\value{
\code{bundles_detail()} returns a list-of-lists containing
relevant details about the bundle
}
\description{
\code{bundles()} takes a list of user provided project titles
to be used to query the HCA API for information about available bundles.

\code{bundles_detail()} takes a unique bundle_id and catalog for
the bundle, and returns details about the specified bundle as a
list-of-lists
}
\examples{
title <- paste(
    "Tabula Muris: Transcriptomic characterization of 20 organs and tissues from Mus musculus",
    "at single cell resolution"
)
filters <- filters( projectTitle = list(is = title) )
bundles(filters = filters)

bundles_facets()

bundles_detail(
    uuid = "0003b020-fd79-4747-94b0-42105f2f941b",
    catalog = "dcp1"
) |> lol() |> lol_filter(is_leaf) |> print(n = Inf)

}
